@@ -1,8 +1,9 @@
+import datetime
 
 import pygame
 
 from .colors import BLACK
-
+import flask
 
 class Page(object):
 
@@ -14,6 +15,8 @@ class Page(object):
         else:
             self.background = None
         self.function = function
+        self._active_widget_num = -1
+        self._prev_active_widget_num = 0
 
     def add_widgets(self, widgets):
         self._widgets += widgets
@@ -34,14 +37,49 @@ class Page(object):
     def render(self, screen):
         """Redraw all widgets to screen"""
         if self.background is not None:
-            screen.blit(self.background, (0,0))
+            screen.blit(self.background, (0, 0))
         else:
             screen.fill(BLACK)
         for widget in self._widgets:
             widget.render(screen)
 
-class GUI(object):
+    def focus_widget(self):
+        """ Wake up the focus system for gesture control.  Will always restart
+        on the last widget that had focus.
+        """
+        self._active_widget_num = self._prev_active_widget_num
 
+    def next_widget(self):
+        self._shift_widgets(1)
+
+    def prev_widget(self):
+        self._shift_widgets(-1)
+
+    def _shift_widgets(self, increment):
+        current_widget_num = self._active_widget_num
+        if current_widget_num >= 0:
+            self._widgets[current_widget_num].focus(False)
+
+        max_widget_num = len(self._widgets) - 1
+
+        while True:
+            # This will cause an infinite loop if none of the widgets can
+            # take focus
+            current_widget_num += increment
+            if current_widget_num > max_widget_num:
+                current_widget_num = 0
+            elif current_widget_num < 0:
+                current_widget_num = max_widget_num
+
+            if self._widgets[current_widget_num].can_focus():
+                break
+
+        self._widgets[current_widget_num].focus(True)
+        self._active_widget_num = current_widget_num
+        self._prev_active_widget_num = current_widget_num
+
+
+class GUI(object):
     FPS = 60
     FADE_TIME = 60
     BLACKOUT_TIME = 300
@@ -61,7 +99,8 @@ class GUI(object):
         self._faded = False
         self._blacked = False
 
-        with open('/sys/class/backlight/rpi_backlight/max_brightness', 'r') as f:
+        with open('/sys/class/backlight/rpi_backlight/max_brightness',
+                  'r') as f:
             max_str = f.readline()
         self.max_brightness = min(int(max_str), 255)
         self.set_brightness(self._bright_level)
@@ -115,7 +154,28 @@ class GUI(object):
             touch.on_release = handle_touches
             touch.on_move = handle_touches
 
+        app = flask.Flask(__name__)
+
+        @app.route('/post', methods=['POST'])
+        def post():
+            message = flask.request.form['message']
+            now = datetime.datetime.now().replace(microsecond=0).time()
+            print(f'[{now.isoformat()}] : {message}')
+
+        @app.route('/stream')
+        def stream():
+            return flask.Response(event_stream(),
+                                  mimetype="text/event-stream")
+
+        def event_stream():
+            now = datetime.datetime.now().replace(microsecond=0).time()
+            message = f"TIME {now}"
+            yield f'data: {message}\n\n'
+
         try:
+            app.debug = True
+            app.run(threaded=True)
+
             while self._running:
                 time = pygame.time.get_ticks()
                 # deltaTime in seconds.
