@@ -66,6 +66,7 @@ class IWidget(ABC):
             font = pygame.font.Font(FONT_NAME, self.font_size)
             self._font_cache[font_key] = font
         self.font = font
+        self._focus = False
 
         self.touches = []
         try:
@@ -98,6 +99,16 @@ class IWidget(ABC):
         """ Render to the device pygame Surface
         """
 
+    def focus(self, enabled):
+        """ Enable or disable this widget.
+        """
+        self._focus = enabled
+
+    def can_focus(self):
+        """ Return True if this widget can accept focus.
+        """
+        return True
+
     def touch_inside(self, touch):
         """
         Test a touch against a generic Widget rectangle
@@ -150,7 +161,7 @@ class IWidget(ABC):
 
     def state_colors(self, active=None):
         active = self.pressed if active is None else active
-        if active:
+        if active or self._focus:
             color = self.color2
             label_color = self.label_color2
         else:
@@ -186,6 +197,9 @@ class Label(IWidget):
 
         self.render_centered_text(surface, self.label, label_color)
 
+    def can_focus(self):
+        return False
+
 
 class Button(IWidget):
 
@@ -587,6 +601,9 @@ class Indicator(IWidget):
 
         self.render_centered_text(surface, label, label_color)
 
+    def can_focus(self):
+        return False
+
 
 def snapped_value_string(value, snap):
     if snap < 0.1:
